@import url("https://fonts.googleapis.com/css?family=Open+Sans&display=swap");
@import url("https://fonts.googleapis.com/css?family=Roboto:400,700&display=swap");
@import url("https://fonts.googleapis.com/css?family=Roboto+Condensed:700&display=swap");

@keyframes fadein {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

body {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
}

.accordion-button:link,
.accordion-button:visited,
.accordion-button:hover,
.accordion-button:active {
  color: #00824d !important;
  text-decoration: none !important;
  border: hidden !important;
  border-color: #FFF !important;
  box-shadow: 0px !important;
}

.accordion-button:focus {
  border: hidden !important;
  outline-style: none;
  box-shadow: none;
  border-color: transparent;
  outline: none !important;
}

.accordion-button:not(.collapsed) {
  color: #00824d !important;
  background-color: #FFF !important;
}

.Select-menu-outer {
  display: block !important;
}

a {
  text-decoration: none;
}

.flex-row {
  display: flex;
  flex-direction: row;
}

.flex-column {
  display: flex;
  flex-direction: column;
}

.justify-space-between {
  justify-content: space-between;
}

.justify-space-around {
  justify-content: space-around;
}

.flex-wrap {
  flex-wrap: wrap;
}

.no-margin {
  margin: 0 !important;
}

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border-width: 0;
}

.ssb-accordion {
  display: grid;
  width: 100%;
}

.ssb-accordion .accordion-header {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 20px;
  font-weight: bold;
  padding: 20px 0;
}

.ssb-accordion .accordion-header:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-accordion .accordion-header .button-grid {
  align-items: center;
  cursor: pointer;
  display: grid;
  grid-column-gap: 28px;
  grid-template-columns: auto 20px;
  margin-right: 12px;
}

.ssb-accordion .accordion-header .expand-icon * {
  color: #00824d;
  font-size: 20px;
}

.ssb-accordion .accordion-header .header-text {
  color: #162327;
}

.ssb-accordion .accordion-header .sub-header {
  color: #00824d;
}

.ssb-accordion .accordion-header:hover .header-text,
.ssb-accordion .accordion-header:hover .sub-header {
  color: #00824d;
}

.ssb-accordion:not(.without-borders)::before {
  border-top: 1px solid #c3dcdc;
  content: "";
  height: 2px;
}

.ssb-accordion:not(.without-borders)::after {
  border-bottom: 1px solid #c3dcdc;
  content: "";
  height: 2px;
  margin-bottom: -1px;
}

.ssb-accordion.with-sub-header .button-grid {
  grid-template-columns: fit-content(100px) auto 20px;
}

.ssb-accordion.with-sub-header .accordion-header .header-text {
  grid-column-start: 2;
}

.ssb-accordion.with-sub-header .accordion-header .sub-header {
  align-self: start;
  grid-column-start: 1;
}

.ssb-accordion .accordion-body {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 16px;
  padding: 8px 50px 8px 0;
}

.ssb-accordion .accordion-body.closed {
  display: none;
  height: 0;
}

.ssb-block-content {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  border-top: 4px solid #1a9d49;
  box-shadow: 0 2px 4px 1px rgba(200, 200, 200, 0.5);
  box-sizing: border-box;
  margin-bottom: 80px;
  max-width: 1200px;
  padding: 100px;
  position: relative;
  width: 100%;
}

.ssb-block-content .section-number {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #62919a;
  font-size: 30px;
  margin-top: -35px;
}

.ssb-block-content .section-number::before {
  background: #1a9d49;
  content: "";
  display: inline-block;
  height: 22px;
  margin-right: 10px;
  width: 10px;
}

.ssb-breadcrumbs {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  font-size: 16px;
  font-stretch: normal;
  line-height: 1.25;
}

.ssb-btn {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  align-items: center;
  background: #fff;
  border: 2px solid #00824d;
  border-radius: 2px;
  color: #00824d;
  display: flex;
  font-size: 16px;
  font-weight: bold;
  height: fit-content;
  line-height: 1.25;
  min-height: 40px;
  padding: 12px 20px;
  text-align: center;
  text-underline-position: under;
  transition: background 0.18s, color 0.18s;
  white-space: nowrap;
}

.ssb-btn:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-btn:hover,
.ssb-btn:active {
  cursor: pointer;
}

.ssb-btn:hover,
.ssb-btn:focus {
  background: #00824d;
  color: #fff;
  text-decoration: underline;
}

.ssb-btn:active {
  background: #274247;
  border: 2px solid #274247;
  color: #fff;
}

.ssb-btn:disabled {
  background: #fff;
  border-color: #c3dcdc;
  color: #c3dcdc;
  cursor: not-allowed;
  font-weight: normal;
}

.ssb-btn:disabled:hover,
.ssb-btn:disabled:focus {
  text-decoration: none;
}

.ssb-btn.negative {
  background: #274247;
  color: #b6e8b8;
  border-color: #b6e8b8;
}

.ssb-btn.negative:hover,
.ssb-btn.negative:focus {
  background: #b6e8b8;
  color: #274247;
}

.ssb-btn.negative:active {
  background: #fff;
  color: #274247;
}

.ssb-btn.negative:disabled {
  background: #274247;
  border-color: #2d6975;
  color: #2d6975;
  font-weight: normal;
}

.ssb-btn.negative:disabled:hover,
.ssb-btn.negative:disabled:focus {
  text-decoration: none;
}

.ssb-btn.primary-btn {
  background: #00824d;
  border: 2px solid #00824d;
  color: #fff;
}

.ssb-btn.primary-btn:hover,
.ssb-btn.primary-btn:active,
.ssb-btn.primary-btn:focus {
  background: #274247;
  border: 2px solid #274247;
  text-decoration: underline;
}

.ssb-btn.primary-btn:disabled {
  background: #c3dcdc;
  border: 2px solid #c3dcdc;
  color: #fff;
  cursor: not-allowed;
  font-weight: normal;
}

.ssb-btn.primary-btn:disabled:hover,
.ssb-btn.primary-btn:disabled:focus {
  text-decoration: none;
}

.ssb-btn.primary-btn.negative {
  background: #b6e8b8;
  border: 2px solid #b6e8b8;
  color: #274247;
}

.ssb-btn.primary-btn.negative:hover,
.ssb-btn.primary-btn.negative:active,
.ssb-btn.primary-btn.negative:focus {
  background: #fff;
  border: 2px solid #fff;
}

.ssb-btn.primary-btn.negative:disabled {
  background: #2d6975;
  border-color: #2d6975;
  color: #274247;
  font-weight: normal;
}

.ssb-btn .sb-icon {
  display: inline-flex;
  font-size: 18px;
  margin-right: 5px;
}

.ssb-card {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  width: 100%;
}

.ssb-card .clickable {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  width: 100%;
}

.ssb-card .clickable:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-card .clickable .card-image {
  display: flex;
}

.ssb-card .clickable .card-image img {
  height: auto;
  width: 100%;
}

.ssb-card .clickable.left-orientation {
  display: inline-flex;
  flex-direction: row;
}

.ssb-card .clickable.left-orientation .card-content {
  height: 214px;
}

.ssb-card .clickable.left-orientation .card-image img {
  height: 214px;
  width: auto;
}

@media screen and (max-width: 767px) {
  .ssb-card .clickable.left-orientation {
    flex-direction: column;
  }

  .ssb-card .clickable.left-orientation .card-content {
    height: 100%;
  }

  .ssb-card .clickable.left-orientation .card-image img {
    height: auto;
    width: 100%;
  }
}

.ssb-card .clickable.top-orientation {
  display: inline-flex;
  flex-direction: column;
}

.ssb-card .clickable:hover {
  text-decoration: none;
}

.ssb-card .clickable:hover.left-orientation .card-content {
  border-left: 5px solid #00824d;
  padding-left: 16px;
}

@media screen and (max-width: 767px) {
  .ssb-card .clickable:hover.left-orientation .card-content {
    border-left: 1px solid #00824d;
    border-top: 5px solid #00824d;
    padding-left: 20px;
    padding-top: 15px;
  }

  .ssb-card .clickable:hover.left-orientation .card-content.with-image {
    padding-top: 16px;
  }
}

.ssb-card .clickable:hover.top-orientation .card-content {
  border-top: 5px solid #00824d;
}

.ssb-card .clickable:hover.top-orientation .card-content.with-image {
  padding-top: 16px;
}

.ssb-card .clickable:hover .card-content {
  border: 1px solid #00824d;
}

.ssb-card .clickable:hover .card-content:not(.with-image) {
  border-top: 5px solid #00824d;
}

.ssb-card .clickable:hover .card-content.with-image .card-title {
  background-color: #00824d;
  border-bottom: none;
  color: #fff;
  margin-bottom: 10px;
}

.ssb-card .clickable:hover .card-content .arrow-icon {
  border: 2px solid #00824d;
  border-radius: 50%;
  margin-bottom: 1px;
  margin-top: 13px;
  margin-left: 1px;
  padding: 1px;
}

.ssb-card .clickable:hover .card-content .card-action {
  align-items: center;
  background-color: #00824d;
  display: flex;
  width: fit-content;
}

.ssb-card .clickable:hover .card-content .card-action .arrow-icon {
  border: none;
  color: #fff;
  margin-top: 0;
  padding: 0;
}

.ssb-card .clickable:hover .card-content .card-action .href-text {
  color: #fff;
}

.ssb-card .card-content {
  background: #fff;
  border: 1px solid #c3dcdc;
  border-top: 5px solid #1a9d49;
  box-sizing: border-box;
  cursor: pointer;
  display: inline-block;
  flex-direction: column;
  padding: 20px;
  width: 100%;
}

.ssb-card .card-content.with-image {
  border-top: 1px solid #c3dcdc;
}

.ssb-card .card-content.with-image .card-title {
  border-bottom: 2px solid #00824d;
  display: table;
}

.ssb-card .card-content.profiled {
  align-items: center;
  display: inline-flex;
  text-align: center;
}

.ssb-card .card-content.profiled .card-title {
  font-size: 28px;
}

.ssb-card .card-content.profiled .card-icon {
  margin-bottom: 20px;
  max-height: 132px;
  max-width: 100%;
  width: 100%;
}

.ssb-card .card-content.profiled .card-icon>* {
  max-height: inherit;
  max-width: inherit;
}

.ssb-card .card-content .arrow-icon {
  box-sizing: initial;
  color: #00824d;
  display: block;
  margin-top: 12px;
  padding: 4px;
}

.ssb-card .card-content .card-action {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  display: flex;
  margin-top: 12px;
}

.ssb-card .card-content .card-action .arrow-icon {
  margin-top: 0;
  padding: 0;
}

.ssb-card .card-content .card-action .href-text {
  color: #162327;
  font-size: 16px;
  padding: 4px;
}

.ssb-card .card-content .card-icon {
  margin-bottom: 16px;
  max-height: 28px;
  max-width: 28px;
  width: 28px;
}

.ssb-card .card-content .card-subtitle {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 14px;
  margin-bottom: 8px;
}

.ssb-card .card-content .card-title {
  display: block;
  font-size: 20px;
  font-weight: bold;
  margin-bottom: 8px;
}

.ssb-card .download-section {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  border: 1px solid #c3dcdc;
  cursor: pointer;
  display: flex;
  height: 60px;
  text-decoration: none;
}

.ssb-card .download-section:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-card .download-section:hover {
  border: 1px solid #1a9d49;
}

.ssb-card .download-section .download-icon {
  color: #00824d;
  margin: 0 18px;
}

.ssb-card .download-section span {
  color: #162327;
  font-size: 16px;
}

.ssb-checkbox {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  cursor: pointer;
  display: block;
  font-size: 16px;
  min-width: 200px;
  outline: none;
  position: relative;
  text-align: left;
  user-select: none;
}

.ssb-checkbox:hover .checkbox-label::before,
.ssb-checkbox:focus .checkbox-label::before {
  border: 2px solid #00824d;
}

.ssb-checkbox input[type=checkbox] {
  cursor: pointer;
  opacity: 0;
  position: absolute;
}

.ssb-checkbox input[type=checkbox]:focus+.checkbox-label::before {
  border: 2px solid #00824d;
}

.ssb-checkbox input[type=checkbox]:checked+.checkbox-label {
  -webkit-print-color-adjust: exact;
  color-adjust: exact;
}

.ssb-checkbox input[type=checkbox]:checked+.checkbox-label::before {
  background: #274247;
}

.ssb-checkbox input[type=checkbox]:checked+.checkbox-label::after {
  border: solid #fff;
  border-width: 0 2px 2px 0;
  box-sizing: initial;
  content: "";
  display: block;
  height: 10px;
  left: 6px;
  position: absolute;
  top: 2px;
  transform: rotate(45deg);
  width: 6px;
}

.ssb-checkbox input[type=checkbox]:disabled+.checkbox-label {
  background: #fff;
  color: #c3dcdc;
  cursor: default;
}

.ssb-checkbox input[type=checkbox]:disabled+.checkbox-label::before {
  border: 1px solid #c3dcdc;
}

.ssb-checkbox .checkbox-label {
  align-items: center;
  cursor: pointer;
  display: flex;
  margin-bottom: 12px;
  position: relative;
}

.ssb-checkbox .checkbox-label::before {
  background: #fff;
  border: 1px solid #274247;
  border-radius: 2px;
  box-sizing: border-box;
  content: "";
  display: block;
  height: 20px;
  margin-right: 12px;
  width: 20px;
}

.ssb-checkbox-group {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  display: inline-block;
}

.ssb-checkbox-group .boxes {
  display: flex;
}

.ssb-checkbox-group .checkbox-group-header {
  font-size: 16px;
  font-weight: bold;
  margin-bottom: 8px;
}

.ssb-checkbox-group input {
  margin: 3px 3px 3px 4px;
}

.ssb-dialog {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  display: flex;
  max-width: 1180px;
  min-width: 100%;
  min-height: 95px;
  width: 100%;
}

.ssb-dialog .icon-panel {
  color: #fff;
  display: flex;
  flex-shrink: 0;
  font-size: 36px;
  justify-content: center;
  padding-top: 20px;
  width: 90px;
}

.ssb-dialog .icon-panel .icon {
  font-size: 40px;
}

.ssb-dialog .dialog-content {
  padding: 16px;
}

.ssb-dialog .dialog-content .dialog-title {
  font-weight: bold;
}

.ssb-dialog .dialog-content .content {
  margin-top: 8px;
}

.ssb-dialog.warning {
  border: 2px solid #ed5935;
}

.ssb-dialog.warning .icon-panel {
  background: #ed5935;
}

.ssb-dialog.info {
  border: 2px solid #3396d2;
}

.ssb-dialog.info .icon-panel {
  background: #3396d2;
}

.ssb-divider {
  border: 0;
  border-top: 1px solid;
  display: block;
  height: 2px;
  margin: 0;
  position: relative;
  width: 100%;
}

.ssb-divider.type-dark {
  border-top-color: #274247;
}

.ssb-divider.type-light {
  border-top-color: #c3dcdc;
}

.ssb-dropdown {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  display: flex;
  flex-direction: column;
  transition: all 0.25s ease-in-out;
  max-width: 350px;
  min-width: 230px;
  position: relative;
}

.ssb-dropdown label,
.ssb-dropdown .dropdown-label {
  font-size: 14px;
  line-height: normal;
  margin-bottom: 5px;
}

.ssb-dropdown .dropdown-interactive-area {
  cursor: pointer;
  position: relative;
}

.ssb-dropdown .dropdown-interactive-area button {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  width: 100%;
  background-color: #fff;
  border: 1px solid #162327;
  box-sizing: border-box;
  cursor: pointer;
  font-size: 16px;
  min-height: 44px;
  padding: 4px 44px 4px 12px;
  text-overflow: ellipsis;
}

.ssb-dropdown .dropdown-interactive-area button:hover,
.ssb-dropdown .dropdown-interactive-area button:focus {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
}

.ssb-dropdown .dropdown-interactive-area .dd-icon {
  color: #00824d;
  font-size: 24px;
  position: absolute;
  right: 12px;
  top: 10px;
  pointer-events: none;
}

.ssb-dropdown .dropdown-interactive-area input {
  background-color: #fff;
  border: 1px solid #162327;
  box-sizing: border-box;
  cursor: pointer;
  font-size: 16px;
  height: 44px;
  padding: 4px 44px 4px 12px;
  text-overflow: ellipsis;
  width: 100%;
}

.ssb-dropdown .dropdown-interactive-area input::placeholder {
  color: #2d6975;
}

.ssb-dropdown .dropdown-interactive-area input:hover,
.ssb-dropdown .dropdown-interactive-area input:focus {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
}

.ssb-dropdown.error input,
.ssb-dropdown.error button.opener {
  border: 1px solid #ed5935;
  outline: 1px solid #ed5935;
}

.ssb-dropdown .list-of-options {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  border: 1px solid #162327;
  left: 0;
  list-style: none;
  margin: 0;
  max-height: 290px;
  min-width: 150px;
  overflow-y: auto;
  padding-left: 0;
  position: absolute;
  scrollbar-color: #b0b0b0 #b0b0b0;
  scrollbar-width: thin;
  top: 44px;
  z-index: 9999;
  width: 100%;
}

.ssb-dropdown .list-of-options .option-list-element {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  cursor: pointer;
  display: block;
  font-size: 16px;
  font-weight: normal;
  line-height: 1.25;
  overflow: hidden;
  padding: 12px;
  text-overflow: ellipsis;
  transition: all 0.18s;
  box-sizing: border-box;
  width: 100%;
}

.ssb-dropdown .list-of-options .option-list-element:hover,
.ssb-dropdown .list-of-options .option-list-element:focus,
.ssb-dropdown .list-of-options .option-list-element.active {
  background: #274247;
  color: #fff;
  z-index: 2;
}

.ssb-dropdown .list-of-options .option-list-element.disabled {
  background: #fff;
  color: #c3dcdc;
  cursor: not-allowed;
  font-weight: normal;
  pointer-events: none;
}

.ssb-dropdown .list-of-options .option-list-element.disabled:hover,
.ssb-dropdown .list-of-options .option-list-element.disabled:focus {
  text-decoration: none;
  background: none;
}

.ssb-dropdown .list-of-options .option-list-element.selected {
  background: #00824d;
  color: #fff;
  font-weight: bold;
}

.ssb-dropdown ::-webkit-scrollbar {
  width: 6px;
}

.ssb-dropdown ::-webkit-scrollbar-track {
  background: #fff;
  border-bottom: 1px solid #162327;
}

.ssb-dropdown ::-webkit-scrollbar-thumb {
  background: #b0b0b0;
  border-radius: 3px;
}

.ssb-dropdown.large {
  max-width: 100%;
  width: 100%;
}

.ssb-dropdown.large .dropdown-interactive-area button {
  max-width: 100%;
  padding: 29px 40px;
  font-size: 20px;
}

.ssb-dropdown.large .list-of-options {
  max-width: 100%;
  width: 100%;
  top: auto;
}

.ssb-dropdown.large .list-of-options .option-list-element {
  max-width: 100%;
  width: 100%;
}

.ssb-dropdown.large .dd-icon {
  box-sizing: initial;
  top: 1px;
  padding: 15px;
}

.ssb-dropdown.large input {
  padding: 40px;
  font-size: 20px;
}

.ssb-fact-box {
  border: 1px solid #1a9d49;
  margin: 16px 0;
  padding: 20px 16px;
  width: 100%;
}

.ssb-fact-box:focus-within {
  outline: #9272fc solid 2px;
}

.ssb-fact-box .accordion-header:focus {
  outline: none;
}

.ssb-fact-box:hover {
  border: 1px solid #00824d;
}

.ssb-footer-wrapper {
  background: #274247;
  box-sizing: border-box;
  color: #fff;
  padding: 36px 112px 58px;
  width: 100%;
}

.ssb-footer-wrapper .top-row {
  border-bottom: 1px solid #fff;
  margin-bottom: 36px;
}

.ssb-footer-wrapper .top-row>* {
  margin-bottom: 36px;
}

.ssb-footer-wrapper .bottom-row {
  margin-top: 100px;
}

.ssb-footer-wrapper .bottom-row>* {
  margin-top: 20px;
}

.ssb-footer-wrapper .bottom-row .global-links>* {
  margin-right: 20px;
}

.ssb-footer-wrapper .bottom-row .social-links>* {
  margin-left: 20px;
}

.ssb-form-error {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  border: 2px solid #ed5935;
  border-left: 4px solid #ed5935;
  display: flex;
  padding: 20px 20px 20px 0;
  width: 100%;
}

.ssb-form-error .error-icon {
  margin: 0 15px;
}

.ssb-form-error .error-icon::before {
  align-items: center;
  background: #ed5935;
  border-radius: 2px;
  color: #fff;
  content: "!";
  display: inline-flex;
  font-size: 18px;
  font-weight: bold;
  height: 28px;
  justify-content: center;
  width: 28px;
}

.ssb-form-error .error-title {
  color: #ed5935;
  font-weight: bold;
  line-height: 1.25;
}

.ssb-form-error ul {
  color: #162327;
  margin-bottom: 0;
  margin-top: 15px;
  padding-left: 18px;
}

.ssb-form-error.negative {
  background: #274247;
}

.ssb-form-error.negative ul {
  color: #fff;
}

.ssb-glossary {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  background-image: linear-gradient(to right, #b6e8b8 50%, #fff 50%);
  background-position: right bottom;
  background-repeat: no-repeat;
  background-size: 200% 100%;
  display: inline-block;
  position: relative;
  transition: all 0.5s ease-out;
}

.ssb-glossary:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-glossary .glossary-text-wrap {
  border-bottom: 1px dotted #00824d;
  display: inline;
  line-height: inherit;
}

.ssb-glossary .glossary-logo {
  color: #1a9d49;
  margin: 2px;
  transition: color 0.2s;
  vertical-align: top;
}

.ssb-glossary:hover,
.ssb-glossary:focus {
  background-position: left bottom;
}

.ssb-glossary:hover .glossary-logo,
.ssb-glossary:focus .glossary-logo {
  color: #162327;
}

.ssb-glossary:hover .glossary-text-wrap,
.ssb-glossary:focus .glossary-text-wrap {
  border-bottom: none;
}

.ssb-glossary .glossary-popup {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  animation: fadein 0.2s;
  display: none;
  font-size: 14px;
  left: 50%;
  margin-left: -135px;
  opacity: 0;
  position: absolute;
  top: 34px;
  transition: opacity 0.18s;
  width: 270px;
  z-index: 999;
}

.ssb-glossary .glossary-popup::after {
  border-color: transparent transparent #274247 transparent;
  border-style: solid;
  border-width: 12px;
  content: "";
  left: 50%;
  margin-left: -12px;
  position: absolute;
  top: -22px;
}

.ssb-glossary .glossary-popup.open {
  display: inline-block;
  opacity: 1;
}

.ssb-glossary .glossary-popup .content-box {
  background: #274247;
  color: #fff;
  padding: 20px;
}

.ssb-glossary .glossary-popup .content-box .ssb-glossary-closing {
  align-items: center;
  display: flex;
  justify-content: center;
  margin-top: 10px;
  user-select: none;
  width: 100%;
}

.ssb-glossary .glossary-popup .content-box .ssb-glossary-closing .icon {
  color: #274247;
  fill: #b6e8b8;
  font-size: 16px;
}

.ssb-glossary .glossary-popup .content-box .ssb-glossary-closing span {
  line-height: 1.43;
  margin-left: 2px;
}

.ssb-glossary .glossary-popup .content-box .info-text {
  color: #fff;
  font-size: 14px;
}

.ssb-header-wrapper {
  box-sizing: border-box;
  padding: 0 114px;
  width: 100%;
}

.ssb-header-wrapper .global-links>* {
  margin-left: 20px;
}

.ssb-picture-card {
  overflow: hidden;
  position: relative;
  display: flex;
  align-items: flex-end;
  width: 280px;
  height: 400px;
  color: #fff !important;
  cursor: pointer;
}

.ssb-picture-card .image-background img {
  top: 0;
  left: 0;
  position: absolute;
  transform: scale(1);
  transition: transform 0.25s ease, -webkit-transform 0.25s ease;
}

.ssb-picture-card:hover img {
  transform: scale(1.1);
}

.ssb-picture-card:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-picture-card .overlay {
  bottom: 0;
  position: absolute;
  padding: 80px 20px 64px;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  width: 280px;
  background-image: linear-gradient(0deg, rgba(39, 66, 71, 0.75), rgba(39, 66, 71, 0.5), transparent);
}

.ssb-picture-card .overlay .il-type {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 16px;
  line-height: 1.25;
  margin-bottom: 12px;
}

.ssb-picture-card .overlay .il-title {
  font-family: "Roboto Condensed", sans-serif !important;
  font-stretch: condensed;
  font-weight: bold;
  font-size: 28px;
  font-weight: bold;
  line-height: 1.43;
  margin-bottom: 12px;
}

.ssb-picture-card.horizontal {
  height: 212px;
  padding: 40px 20px;
  width: 380px;
}

.ssb-picture-card.horizontal .image-background {
  height: 212px;
  width: 380px;
}

.ssb-picture-card.horizontal .overlay {
  width: 380px;
  padding: 40px 20px;
  left: 0;
}

.ssb-input {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  cursor: text;
  display: flex;
  flex-direction: column;
  max-width: 400px;
  position: relative;
  width: 100%;
}

.ssb-input:hover input {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
}

.ssb-input:hover input:disabled {
  border: 1px solid #274247;
}

.ssb-input .input-wrapper {
  display: flex;
}

.ssb-input .input-wrapper ::placeholder {
  color: #2d6975;
  font-size: 14px;
  opacity: 1;
}

.ssb-input label {
  color: #162327;
  cursor: text;
  font-size: 14px;
  margin-bottom: 5px;
  user-select: none;
}

.ssb-input input {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  border: 1px solid #274247;
  box-sizing: border-box;
  color: #162327;
  font-size: 16px;
  height: 44px;
  padding: 12px;
  text-overflow: ellipsis;
  width: 100%;
}

.ssb-input input.with-icon {
  padding: 4px 44px 4px 10px;
}

.ssb-input input:disabled {
  border: 1px solid #274247;
  cursor: not-allowed;
}

.ssb-input input:focus {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
  outline-offset: 0;
}

.ssb-input.negative .input-wrapper ::placeholder {
  color: #fff;
  opacity: 1;
}

.ssb-input.negative:hover input {
  border: 1px solid #b6e8b8;
  outline: 1px solid #b6e8b8;
}

.ssb-input.negative:hover input:disabled {
  border: 1px solid #fff;
}

.ssb-input.negative label {
  color: #fff;
}

.ssb-input.negative input {
  background: transparent;
  border: 1px solid #fff;
  color: #fff;
}

.ssb-input.negative input:disabled {
  border: 1px solid #fff;
}

.ssb-input.negative input:focus {
  border: 1px solid #b6e8b8;
  outline: 1px solid #b6e8b8;
  outline-offset: 0;
}

.ssb-input.negative .icon-wrapper>* {
  color: #b6e8b8;
}

.ssb-input.negative .icon-wrapper.search-icon {
  cursor: pointer;
}

.ssb-input.negative .icon-wrapper.search-icon:hover,
.ssb-input.negative .icon-wrapper.search-icon:focus {
  background: #fff;
}

.ssb-input.negative .icon-wrapper.search-icon:hover>*,
.ssb-input.negative .icon-wrapper.search-icon:focus>* {
  color: #274247;
}

.ssb-input.negative.error input {
  border: 1px solid #ed5935;
  outline: 1px solid #ed5935;
}

.ssb-input.negative.error .icon-wrapper>* {
  color: #ed5935;
}

.ssb-input.error input {
  border: 1px solid #ed5935;
  outline: 1px solid #ed5935;
}

.ssb-input.error .icon-wrapper>* {
  color: #ed5935;
}

.ssb-input .icon-wrapper {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  align-items: center;
  display: flex;
  font-size: 18px;
  height: 44px;
  justify-content: center;
  margin-left: -44px;
  width: 44px;
}

.ssb-input .icon-wrapper:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-input .icon-wrapper>* {
  color: #00824d;
}

.ssb-input .icon-wrapper.search-icon {
  cursor: pointer;
}

.ssb-input .icon-wrapper.search-icon:hover,
.ssb-input .icon-wrapper.search-icon:focus {
  background: #00824d;
}

.ssb-input .icon-wrapper.search-icon:hover>*,
.ssb-input .icon-wrapper.search-icon:focus>* {
  color: #fff;
}

.ssb-input.input-lg {
  max-width: 100%;
}

.ssb-input.input-lg .search-icon {
  margin-left: -78px;
  height: 77px;
  width: 77px;
  padding: 17px;
}

.ssb-input.input-lg input {
  width: 100%;
  padding: 38px 40px;
  font-weight: bold;
  font-size: 20px;
}

.ssb-input.input-lg input::placeholder {
  font-weight: normal;
  font-size: 20px;
}

.ssb-input-error {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #ed5935;
  color: #fff;
  display: flex;
  font-size: 14px;
  font-weight: bold;
  justify-content: center;
  line-height: normal;
  margin-top: 12px;
  padding: 4px 8px;
  position: relative;
}

.ssb-input-error.negative {
  color: #274247;
}

.ssb-input-error::before {
  border-color: transparent transparent #ed5935 transparent;
  border-style: solid;
  border-width: 8px;
  content: "";
  position: absolute;
  top: -16px;
}

.ssb-key-figures {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #274247;
  display: flex;
}

.ssb-key-figures .kf-icon {
  color: #274247;
  display: inline-flex;
}

.ssb-key-figures .kf-icon>* {
  width: 100%;
}

.ssb-key-figures .kf-changes {
  align-items: flex-end;
  display: flex;
  margin-top: 12px;
}

.ssb-key-figures .kf-changes .changes-icon {
  margin-right: 4px;
}

.ssb-key-figures .kf-changes .changes-text {
  font-weight: bold;
  font-size: 20px;
}

.ssb-key-figures .kf-changes .changes-period {
  font-size: 16px;
}

.ssb-key-figures.large .kf-icon {
  margin-right: 36px;
  max-height: 195px;
  max-width: 195px;
  width: 195px;
}

.ssb-key-figures.large .subtitle {
  margin-bottom: 30px;
  margin-left: 4px;
}

@media screen and (max-width: 767px) {
  .ssb-key-figures.large .subtitle {
    margin-bottom: 14px;
  }
}

.ssb-key-figures.medium .kf-icon {
  margin-right: 28px;
  max-height: 150px;
  max-width: 150px;
  width: 150px;
}

.ssb-key-figures.medium .subtitle {
  margin-bottom: 19px;
  margin-left: 4px;
}

@media screen and (max-width: 767px) {
  .ssb-key-figures.medium .subtitle {
    margin-bottom: 8px;
  }
}

.ssb-key-figures.small .kf-icon {
  margin-right: 20px;
  max-height: 108px;
  max-width: 108px;
  width: 108px;
}

.ssb-key-figures.small .subtitle {
  margin-bottom: 9px;
  margin-left: 4px;
}

@media screen and (max-width: 767px) {
  .ssb-key-figures .kf-icon {
    display: none;
  }
}

.ssb-key-figures .number-section {
  align-items: flex-end;
  display: flex;
  flex-wrap: wrap;
}

.ssb-key-figures .kf-time {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 16px;
  margin-top: 4px;
}

.ssb-key-figures .kf-title {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 20px;
  font-weight: bold;
  line-height: normal;
  margin: 0;
}

.ssb-key-figures .kf-title.subtitle {
  color: #274247;
}

.ssb-key-figures .no-number {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #62919a;
  font-size: 20px;
  font-weight: bold;
}

.ssb-key-figures.green-box {
  position: relative;
  background: #ecfeed;
  padding: 38px 40px;
  border-radius: 2px;
  width: 100%;
}

.ssb-key-figures.green-box::after {
  top: 100%;
  left: 50%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
  border-color: rgba(229, 254, 230, 0);
  border-top-color: #ecfeed;
  border-width: 42px;
  margin-left: -42px;
}

.ssb-lead-paragraph {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 20px;
  line-height: 32px;
  max-width: 680px;
}

.ssb-lead-paragraph.negative {
  color: #fff;
}

.ssb-link {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  background-image: linear-gradient(120deg, #00824d 0%, #00824d 100%);
  background-position: 0 100%;
  background-repeat: no-repeat;
  background-size: 100% 0;
  border-bottom: 1px solid #00824d;
  color: #00824d;
  cursor: pointer;
  display: inline;
  font-size: 16px;
  line-height: 1.7;
  margin-top: -3px;
  margin-bottom: -2px;
  padding: 0 1px 2px;
  position: relative;
  text-decoration: none;
  transition: background-size 0.2s ease-in, color 0.1s;
}

.ssb-link .icon-wrapper {
  display: flex;
  margin-right: 4px;
  margin-top: 5px;
}

.ssb-link.header {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  border-bottom-width: 2px;
  font-size: 20px;
  font-weight: bold;
}

.ssb-link.header .link-text {
  color: #162327;
}

.ssb-link:hover,
.ssb-link:focus {
  background-size: 100% 100%;
  color: #fff;
  outline: 0;
  text-decoration: none;
}

.ssb-link:hover .link-text,
.ssb-link:focus .link-text {
  color: #fff;
}

.ssb-link.negative {
  background-image: linear-gradient(120deg, #b6e8b8 0%, #b6e8b8 100%);
  border-bottom: 1px solid #b6e8b8;
  color: #b6e8b8;
}

.ssb-link.negative .link-text {
  color: #b6e8b8;
}

.ssb-link.negative.header {
  border-bottom-width: 2px;
}

.ssb-link.negative.header .link-text {
  color: #fff;
}

.ssb-link.negative.with-icon {
  padding: 2px 2px 0;
  border-bottom: none;
  display: inline-flex;
  align-items: flex-start;
}

.ssb-link.negative.with-icon i {
  font-size: 20px;
}

.ssb-link.negative.with-icon .link-text {
  color: #fff;
}

.ssb-link.negative.with-icon:hover,
.ssb-link.negative.with-icon:focus {
  color: #274247;
}

.ssb-link.negative.with-icon:hover .link-text,
.ssb-link.negative.with-icon:focus .link-text {
  color: #274247;
}

.ssb-link.negative:hover,
.ssb-link.negative:focus {
  color: #274247;
  outline: 0;
}

.ssb-link.negative:hover .link-text,
.ssb-link.negative:focus .link-text {
  color: #274247;
}

.ssb-link.profiled {
  border-bottom-width: 2px;
  font-size: 18px;
  font-weight: bold;
}

.ssb-link.with-icon {
  padding: 2px 2px 0;
  border-bottom: none;
  display: inline-flex;
  align-items: flex-start;
}

.ssb-link.with-icon i {
  font-size: 16px;
}

.ssb-link.with-icon .link-text {
  color: #162327;
}

.ssb-link.with-icon:hover,
.ssb-link.with-icon:focus {
  color: #fff;
}

.ssb-link.with-icon:hover .link-text,
.ssb-link.with-icon:focus .link-text {
  color: #fff;
}

.ssb-link .link-text {
  color: #00824d;
  transition: color 0.1s;
}

.ssb-link .link-text:hover,
.ssb-link .link-text:focus {
  color: #fff;
  outline: 0;
}

.ssb-nested-accordion {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  display: grid;
  margin-top: 8px;
  min-width: 300px;
  width: 100%;
}

.ssb-nested-accordion .nested-accordion-header {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
}

.ssb-nested-accordion .nested-accordion-header:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-nested-accordion .nested-accordion-header .button-grid {
  align-items: center;
  cursor: pointer;
  display: grid;
  grid-column-gap: 16px;
  grid-template-columns: 15px 1fr;
}

.ssb-nested-accordion .nested-accordion-header .expand-icon {
  color: #00824d;
  font-size: 16px;
}

.ssb-nested-accordion .nested-accordion-header .header-text {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 16px;
  font-weight: bold;
  line-height: 1.25;
}

.ssb-nested-accordion .nested-accordion-header:hover .header-text {
  color: #00824d;
}

.ssb-nested-accordion .nested-accordion-header.open .header-text,
.ssb-nested-accordion .nested-accordion-header.open .sub-header {
  color: #00824d;
}

.ssb-nested-accordion .nested-accordion-body {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 16px;
  padding: 10px 10px 10px 30px;
}

.ssb-nested-accordion .nested-accordion-body.closed {
  display: none;
  height: 0;
}

.ssb-number {
  font-family: "Roboto Condensed", sans-serif !important;
  font-stretch: condensed;
  font-weight: bold;
  color: #274247;
  line-height: normal;
  white-space: nowrap;
}

.ssb-number.small {
  font-size: 56px;
}

@media screen and (max-width: 767px) {
  .ssb-number.small {
    font-size: 56px;
  }
}

.ssb-number.medium {
  font-size: 100px;
}

@media screen and (max-width: 767px) {
  .ssb-number.medium {
    font-size: 56px;
  }
}

.ssb-number.large {
  font-size: 148px;
}

@media screen and (max-width: 767px) {
  .ssb-number.large {
    font-size: 77px;
  }
}

.ssb-pagination {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  display: flex;
  line-height: 1.25;
}

.ssb-pagination .nav-button-square {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  align-items: center;
  border: 1px solid transparent;
  border-radius: 2px;
  color: #00824d;
  cursor: pointer;
  display: flex;
  height: 30px;
  justify-content: center;
  margin: 0 4px;
  width: 30px;
}

.ssb-pagination .nav-button-square:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-pagination .nav-button-square.selected {
  background: #00824d;
  color: #fff;
  font-weight: bold;
}

.ssb-pagination .nav-button-square:hover {
  border: 1px solid #00824d;
  border-radius: 2px;
  font-weight: bold;
}

.ssb-pagination .dotted-indicator {
  align-items: center;
  display: flex;
  justify-content: center;
  margin: 0 4px;
  width: 30px;
}

.ssb-pagination .direction-button {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  align-items: center;
  border: 1px solid transparent;
  cursor: pointer;
  display: flex;
  font-size: 16px;
  height: 30px;
  justify-content: center;
  padding: 4px 10px;
}

.ssb-pagination .direction-button:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-pagination .direction-button:first-of-type {
  text-align: right;
}

.ssb-pagination .direction-button .chevron-icon {
  color: #00824d;
  font-size: 16px;
}

.ssb-pagination .direction-button:hover {
  border-radius: 2px;
  color: #00824d;
  font-weight: bold;
  border: 1px solid #00824d;
}

.ssb-pagination .direction-button.previous .chevron-icon {
  margin-right: 2px;
}

.ssb-pagination .direction-button.next .chevron-icon {
  margin-left: 2px;
}

.ssb-paragraph {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 16px;
  line-height: 28px;
  max-width: 580px;
}

.ssb-paragraph.negative {
  color: #fff;
}

.ssb-quote {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background-image: linear-gradient(120deg, #ecfeed 0%, #ecfeed 100%);
  background-position: 0 100%;
  background-repeat: no-repeat;
  background-size: 100% 50%;
  font-size: 20px;
  font-style: normal;
  letter-spacing: normal;
  line-height: 1.6;
}

.ssb-quote.negative {
  background-image: linear-gradient(120deg, #075745 0%, #075745 100%);
  color: #fff;
}

.ssb-radio {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  cursor: pointer;
  display: block;
  font-size: 16px;
  min-width: 200px;
  outline: none;
  position: relative;
  text-align: left;
  user-select: none;
}

.ssb-radio:hover .radio-label::before,
.ssb-radio:focus .radio-label::before {
  border: 2px solid #00824d;
}

.ssb-radio input[type=radio] {
  cursor: pointer;
  opacity: 0;
  position: absolute;
}

.ssb-radio input[type=radio]:focus+.radio-label::before {
  border: 2px solid #00824d;
}

.ssb-radio input[type=radio]:checked+.radio-label {
  -webkit-print-color-adjust: exact;
  color-adjust: exact;
}

.ssb-radio input[type=radio]:checked+.radio-label::after {
  background: #274247;
  border-radius: 50%;
  content: "";
  display: block;
  height: 12px;
  left: 4px;
  position: absolute;
  top: 4px;
  transform: rotate(45deg);
  width: 12px;
}

.ssb-radio input[type=radio]:disabled+.radio-label {
  background: #fff;
  color: #c3dcdc;
  cursor: default;
}

.ssb-radio input[type=radio]:disabled+.radio-label::before {
  border: 1px solid #c3dcdc;
}

.ssb-radio .radio-label {
  align-items: center;
  cursor: pointer;
  display: flex;
  margin-bottom: 12px;
  position: relative;
}

.ssb-radio .radio-label::before {
  background: #fff;
  border: 1px solid #274247;
  border-radius: 50%;
  box-sizing: border-box;
  content: "";
  display: block;
  height: 20px;
  margin-right: 12px;
  width: 20px;
}

.ssb-radio-group {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  display: inline-block;
}

.ssb-radio-group .boxes {
  display: flex;
}

.ssb-radio-group .radio-group-header {
  font-size: 16px;
  font-weight: bold;
  margin-bottom: 8px;
}

.ssb-references {
  display: inline-flex;
  flex-direction: column;
}

.ssb-references .reference-header {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-weight: bold;
  font-size: 16px;
  line-height: 1.25;
}

.ssb-sticky-menu {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  background-color: #fff;
  border: solid 1px #c3dcdc;
  box-shadow: 2px 2px 10px 0 rgba(206, 205, 205, 0.5);
  color: #162327;
  display: flex;
  justify-content: center;
  line-height: normal;
  position: sticky;
  top: 0;
  width: 100%;
}

.ssb-sticky-menu .menu-content {
  max-width: 1200px;
  width: 100%;
}

.ssb-sticky-menu .chevron-down-icon {
  color: #00824d;
  font-size: 18px;
  margin-right: 2px;
}

.ssb-sticky-menu input {
  min-width: 180px;
  width: 100%;
}

.ssb-sticky-menu .input-header {
  color: #274247;
  font-size: 18px;
  font-weight: bold;
  margin-right: 10px;
  white-space: nowrap;
}

.ssb-table-link {
  display: flex;
  text-decoration: none;
}

.ssb-table-link:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-table-link .tl-icon {
  box-sizing: initial;
  color: #00824d;
  display: inline-flex;
  float: left;
  height: 22px;
  margin-right: 20px;
  margin-top: 4px;
  margin-left: 4px;
  width: 22px;
}

.ssb-table-link .tl-info {
  display: inline-block;
}

.ssb-table-link .tl-text {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #00824d;
  font-weight: bold;
  font-size: 20px;
}

.ssb-table-link .tl-description {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  display: block;
  font-weight: bold;
  font-size: 20px;
  line-height: 1.6;
  margin-top: 4px;
}

.ssb-table-link:hover,
.ssb-table-link:focus {
  text-decoration: none;
}

.ssb-table-link:hover .tl-icon,
.ssb-table-link:focus .tl-icon {
  border: 2px solid #00824d;
  border-radius: 50%;
  margin-top: 0;
  margin-left: 0;
  margin-right: 16px;
  padding: 2px;
}

.ssb-table-link:hover .tl-description,
.ssb-table-link:focus .tl-description {
  color: #00824d;
}

.ssb-tabs {
  display: flex;
  flex-direction: row;
}

.ssb-tabs .navigation-item {
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  cursor: pointer;
  display: flex;
  font-size: 16px;
  font-weight: bold;
  justify-content: center;
  line-height: 1.25;
  outline: none;
  padding: 20px 0;
  position: relative;
  text-align: center;
  text-decoration: none;
  transition: background 0.2s;
}

.ssb-tabs .navigation-item:not(:last-of-type) {
  margin-right: 40px;
}

.ssb-tabs .navigation-item::before {
  background: #274247;
  bottom: 0;
  content: "";
  display: block;
  height: 0;
  left: 0;
  position: absolute;
  transition: all 0.2s;
  width: 100%;
}

.ssb-tabs .navigation-item.active::before {
  background: #1a9d49;
  height: 4px;
}

.ssb-tabs .navigation-item:hover::before,
.ssb-tabs .navigation-item:focus::before {
  height: 4px;
}

.ssb-tag {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background-color: transparent;
  border: none;
  color: inherit;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  padding: 0;
  text-align: left;
  align-items: center;
  background: #fff;
  border: 1px solid #00824d;
  border-radius: 20px;
  color: #00824d;
  display: flex;
  font-size: 16px;
  font-weight: bold;
  height: 36px;
  line-height: 1.25;
  min-height: 26px;
  padding: 8px 16px;
  text-align: center;
  transition: background 0.18s, color 0.18s;
  white-space: nowrap;
}

.ssb-tag:focus {
  outline: #9272fc solid 2px;
  outline-offset: 2px;
}

.ssb-tag:hover,
.ssb-tag:active {
  cursor: pointer;
}

.ssb-tag:hover,
.ssb-tag:focus {
  background: #00824d;
  color: #fff;
}

.ssb-tag:active {
  background: #274247;
  border: 2px solid #274247;
  color: #fff;
}

.ssb-tag .st-icon {
  display: inline-flex;
  font-size: 18px;
  margin-right: 5px;
}

.ssb-text-wrapper {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 16px;
  font-style: normal;
  letter-spacing: normal;
  line-height: 1.7;
  max-width: 580px;
}

.ssb-text-wrapper.small-text {
  font-size: 14px;
  line-height: 24px;
}

.ssb-text-wrapper.negative {
  color: #fff;
}

.ssb-text-area {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  cursor: text;
  display: flex;
  flex-direction: column;
  min-width: 200px;
  position: relative;
}

.ssb-text-area:hover textarea {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
}

.ssb-text-area:hover textarea:disabled {
  border: 1px solid #274247;
}

.ssb-text-area textarea {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background: #fff;
  border: 1px solid #274247;
  box-sizing: border-box;
  color: #162327;
  font-size: 16px;
  line-height: 1.25;
  min-height: 44px;
  min-width: 200px;
  padding: 11px 12px;
  width: 100%;
}

.ssb-text-area textarea:focus {
  border: 1px solid #00824d;
  outline: 1px solid #00824d;
  outline-offset: 0;
}

.ssb-text-area label {
  color: #162327;
  font-size: 14px;
  margin-bottom: 5px;
}

.ssb-text-area.negative .text-area-wrapper ::placeholder {
  color: #fff;
  opacity: 1;
}

.ssb-text-area.negative:hover textarea {
  border: 1px solid #b6e8b8;
  outline: 1px solid #b6e8b8;
}

.ssb-text-area.negative:hover textarea:disabled {
  border: 1px solid #fff;
}

.ssb-text-area.negative label {
  color: #fff;
}

.ssb-text-area.negative textarea {
  background: transparent;
  border: 1px solid #fff;
  color: #fff;
}

.ssb-text-area.negative textarea:disabled {
  border: 1px solid #fff;
}

.ssb-text-area.negative textarea:focus {
  border: 1px solid #b6e8b8;
  outline: 1px solid #b6e8b8;
  outline-offset: 0;
}

.ssb-text-area.negative.error textarea {
  border: 1px solid #ed5935;
  outline: 1px solid #ed5935;
}

.ssb-text-area.error textarea {
  border: 1px solid #ed5935;
  outline: 1px solid #ed5935;
}

.ssb-title {
  color: #162327;
  margin-top: 0;
}

.ssb-title.negative {
  color: #fff;
}

h1.ssb-title {
  font-family: "Roboto Condensed", sans-serif !important;
  font-stretch: condensed;
  font-weight: bold;
  font-size: 56px;
  font-weight: bold;
  line-height: 80px;
}

h2.ssb-title {
  font-family: "Roboto Condensed", sans-serif !important;
  font-stretch: condensed;
  font-weight: bold;
  font-size: 28px;
  font-weight: bold;
  line-height: 40px;
}

h3.ssb-title {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 20px;
  font-weight: bold;
  line-height: 32px;
}

h4.ssb-title {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 16px;
  font-weight: bold;
  line-height: 28px;
}

h5.ssb-title {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 18px;
  font-weight: bold;
  line-height: 1.7;
}

h6.ssb-title {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  font-size: 16px;
  font-weight: bold;
  line-height: 1.7;
}

@media screen and (max-width: 767px) {
  h1.ssb-title {
    font-size: 44px;
    line-height: 56px;
  }

  h2.ssb-title {
    font-size: 28px;
    line-height: 36px;
  }
}

.ssb-mark {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  background-color: #ecfeed;
  font-style: normal;
  letter-spacing: normal;
  line-height: 1.6;
}

.ssb-mark.negative {
  background-color: #075745;
  color: #fff;
}

mark::before,
mark::after {
  clip-path: inset(100%);
  clip: rect(1px, 1px, 1px, 1px);
  height: 1px;
  overflow: hidden;
  position: absolute;
  white-space: nowrap;
  width: 1px;
}

mark::before {
  content: " [highlight start] ";
}

mark::after {
  content: " [highlight end] ";
}

.ssb-category-link {
  font-family: "Open Sans", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  align-items: center;
  background-color: #fff;
  background-image: linear-gradient(120deg, #00824d 0%, #00824d 100%);
  background-position: 0 100%;
  background-repeat: no-repeat;
  background-size: 100% 0;
  border: 1px solid #c3dcdc;
  border-bottom: 3px solid #00824d;
  color: #00824d;
  cursor: pointer;
  display: block;
  font-size: 16px;
  padding: 20px 40px;
  line-height: 1.7;
  position: relative;
  text-decoration: none;
  transition: background-size 0.2s ease-in, color 0.1s;
  width: 100%;
  box-sizing: border-box;
}

@media screen and (max-width: 767px) {
  .ssb-category-link {
    padding: 20px;
  }
}

.ssb-category-link .div-wrapper::after {
  content: "";
  display: table;
  clear: both;
}

.ssb-category-link .div-wrapper {
  display: grid;
  grid-template-columns: auto 24px;
  grid-template-rows: auto auto;
}

.ssb-category-link .icon-wrapper {
  grid-row: 1/3;
  grid-column: 2;
  align-self: center;
  align-content: center;
}

.ssb-category-link .title-wrapper {
  grid-column: 1;
  grid-row: 1;
}

.ssb-category-link .sub-wrapper {
  grid-column: 1;
  grid-row: 2;
  margin-top: 3px;
}

.ssb-category-link .link-title-text {
  font-family: "Roboto", sans-serif !important;
  font-stretch: normal;
  font-weight: normal;
  color: #162327;
  font-size: 20px;
  font-weight: bold;
}

.ssb-category-link .link-sub-text {
  color: #162327;
}

.ssb-category-link:hover,
.ssb-category-link:focus {
  background-size: 100% 100%;
  color: #fff;
  outline: 0;
  text-decoration: none;
}

.ssb-category-link:hover .link-title-text,
.ssb-category-link:hover .link-sub-text,
.ssb-category-link:focus .link-title-text,
.ssb-category-link:focus .link-sub-text {
  color: #fff;
}

.ssb-category-link .link-text {
  color: #00824d;
  transition: color 0.1s;
}

.ssb-category-link .link-text:hover,
.ssb-category-link .link-text:focus {
  color: #fff;
  outline: 0;
}
